@@ -130,7 +130,7 @@ remote_desktop_session_sources_selected (RemoteDesktopSession *session,
 static void
 remote_desktop_dialog_handle_free (RemoteDesktopDialogHandle *dialog_handle)
 {
-  g_clear_pointer ((GtkWindow**)&dialog_handle->dialog, gtk_window_destroy);
+  g_clear_pointer (&dialog_handle->dialog, gtk_window_destroy);
   g_clear_object (&dialog_handle->external_parent);
   g_object_unref (dialog_handle->request);
 
