@@ -868,6 +868,9 @@ screen_cast_session_close (Session *session)
                    error->message);
       g_clear_object (&screen_cast_session->gnome_screen_cast_session);
     }
+
+  g_clear_pointer (&screen_cast_session->dialog_handle,
+                   screen_cast_dialog_handle_close);
 }
 
 static void
